@@ -7,19 +7,19 @@ import networkx as nx
 from qiskit import Aer
 from qiskit.tools.visualization import plot_histogram
 from qiskit.circuit.library import TwoLocal
-from qiskit_optimization.applications import Maxcut, Tsp
+from qiskit_optimization.applications import Tsp
 from qiskit.algorithms import VQE, NumPyMinimumEigensolver
 from qiskit.algorithms.optimizers import SPSA
 from qiskit.utils import algorithm_globals, QuantumInstance
 from qiskit_optimization.algorithms import MinimumEigenOptimizer
 from qiskit_optimization.problems import QuadraticProgram
 
-# Input the number of nodes
 
+# Ask to input the number of nodes
 while True:
     try:
         
-        n = int(input("Type '5' to create a graph of 5 nodes: "))
+        n = int(input("Type the number of nodes to create a graph"))
         
     except ValueError:
         print( "This is not a valid input")
@@ -27,17 +27,15 @@ while True:
     else:
         break
 
-#Generating a graph of 4 nodes
+# Generating a graph of nodes
+num_qubits = n**2
+tsp = Tsp.create_random_instance(n, seed=123)
+adj_matrix = nx.to_numpy_matrix(tsp.graph)
+print("distance\n", adj_matrix)
 
 G = nx.Graph()
-G.add_nodes_from(np.arange(0, n, 1))
-elist = [(0, 1, 1.0), (0, 2, 1.0), (0, 3, 1.0), (1, 2, 1.0), (2, 3, 1.0), (0, 4, 1.0), (3, 4, 1.0)]
-# tuple is (i,j,weight) where (i,j) is the edge
-G.add_weighted_edges_from(elist)
-
-colors = ["r" for node in G.nodes()]
-pos = nx.spring_layout(G)
-
+colors = ["r" for node in tsp.graph.nodes]
+pos = [tsp.graph.nodes[node]["pos"] for node in tsp.graph.nodes]
 
 def draw_graph(G, colors, pos):
     default_axes = plt.axes(frameon=True)
@@ -45,118 +43,9 @@ def draw_graph(G, colors, pos):
     edge_labels = nx.get_edge_attributes(G, "weight")
     nx.draw_networkx_edge_labels(G, pos=pos, edge_labels=edge_labels)
 
-
-draw_graph(G, colors, pos)
-
-# Computing the weight matrix from the random graph
-w = np.zeros([n, n])
-for i in range(n):
-    for j in range(n):
-        temp = G.get_edge_data(i, j, default=0)
-        if temp != 0:
-            w[i, j] = temp["weight"]
-print(w)
-
-best_cost_brute = 0
-for b in range(2**n):
-    x = [int(t) for t in reversed(list(bin(b)[2:].zfill(n)))]
-    cost = 0
-    for i in range(n):
-        for j in range(n):
-            cost = cost + w[i, j] * x[i] * (1 - x[j])
-    if best_cost_brute < cost:
-        best_cost_brute = cost
-        xbest_brute = x
-    print("case = " + str(x) + " cost = " + str(cost))
-
-colors = ["r" if xbest_brute[i] == 0 else "c" for i in range(n)]
-draw_graph(G, colors, pos)
-print("\nBest solution = " + str(xbest_brute) + " cost = " + str(best_cost_brute))
-
-max_cut = Maxcut(w)
-qp = max_cut.to_quadratic_program()
-print(qp.prettyprint())
-
-qubitOp, offset = qp.to_ising()
-print("Offset:", offset)
-print("Ising Hamiltonian:")
-print(str(qubitOp))
-
-# solving Quadratic Program using exact classical eigensolver
-exact = MinimumEigenOptimizer(NumPyMinimumEigensolver())
-result = exact.solve(qp)
-print(result.prettyprint())
-
-# Making the Hamiltonian in its full form and getting the lowest eigenvalue and eigenvector
-ee = NumPyMinimumEigensolver()
-result = ee.compute_minimum_eigenvalue(qubitOp)
-
-x = max_cut.sample_most_likely(result.eigenstate)
-print("energy:", result.eigenvalue.real)
-print("max-cut objective:", result.eigenvalue.real + offset)
-print("solution:", x)
-print("solution objective:", qp.objective.evaluate(x))
-
-colors = ["r" if x[i] == 0 else "c" for i in range(n)]
-draw_graph(G, colors, pos)
-
-algorithm_globals.random_seed = 123
-seed = 10598
-backend = Aer.get_backend("aer_simulator_statevector")
-quantum_instance = QuantumInstance(backend, seed_simulator=seed, seed_transpiler=seed)
-
-# construct VQE
-spsa = SPSA(maxiter=300)
-ry = TwoLocal(qubitOp.num_qubits, "ry", "cz", reps=5, entanglement="linear")
-vqe = VQE(ry, optimizer=spsa, quantum_instance=quantum_instance)
-
-# run VQE
-result = vqe.compute_minimum_eigenvalue(qubitOp)
-
-# print results
-x = max_cut.sample_most_likely(result.eigenstate)
-print("energy:", result.eigenvalue.real)
-print("time:", result.optimizer_time)
-print("max-cut objective:", result.eigenvalue.real + offset)
-print("solution:", x)
-print("solution objective:", qp.objective.evaluate(x))
-
-# plot results
-colors = ["r" if x[i] == 0 else "c" for i in range(n)]
-draw_graph(G, colors, pos)
-
-# create minimum eigen optimizer based on VQE
-vqe_optimizer = MinimumEigenOptimizer(vqe)
-
-# solve quadratic program
-result = vqe_optimizer.solve(qp)
-print(result.prettyprint())
-
-colors = ["r" if result.x[i] == 0 else "c" for i in range(n)]
-draw_graph(G, colors, pos)
-
-# Ask to input the number of nodes
-while True:
-    try:
-        
-        n = int(input("Type '3' to create a graph of 3 nodes: "))
-        
-    except ValueError:
-        print( "This is not a valid input")
-        continue
-    else:
-        break
-
-# Generating a graph of 3 nodes
-num_qubits = n**2
-tsp = Tsp.create_random_instance(n, seed=123)
-adj_matrix = nx.to_numpy_matrix(tsp.graph)
-print("distance\n", adj_matrix)
-
-colors = ["r" for node in tsp.graph.nodes]
-pos = [tsp.graph.nodes[node]["pos"] for node in tsp.graph.nodes]
 draw_graph(tsp.graph, colors, pos)
 
+
 from itertools import permutations
 
 
@@ -216,6 +105,11 @@ print("Offset:", offset)
 print("Ising Hamiltonian:")
 print(str(qubitOp))
 
+# solving Quadratic Program using exact classical eigensolver
+exact = MinimumEigenOptimizer(NumPyMinimumEigensolver())
+result = exact.solve(qp)
+print(result.prettyprint())
+
 result = exact.solve(qubo)
 print(result.prettyprint())
 
@@ -234,7 +128,12 @@ draw_tsp_solution(tsp.graph, z, colors, pos)
 
 algorithm_globals.random_seed = 123
 seed = 10598
-backend = Aer.get_backend("aer_simulator_statevector")
+
+if n>3:
+    backend = Aer.get_backend("qasm_simulator")
+else:
+    backend = Aer.get_backend("aer_simulator_statevector")
+    
 quantum_instance = QuantumInstance(backend, seed_simulator=seed, seed_transpiler=seed)
 
 spsa = SPSA(maxiter=300)
@@ -254,7 +153,12 @@ draw_tsp_solution(tsp.graph, z, colors, pos)
 
 algorithm_globals.random_seed = 123
 seed = 10598
-backend = Aer.get_backend("aer_simulator_statevector")
+
+if n>3:
+    backend = Aer.get_backend("qasm_simulator")
+else:
+    backend = Aer.get_backend("aer_simulator_statevector")
+    
 quantum_instance = QuantumInstance(backend, seed_simulator=seed, seed_transpiler=seed)
 
 # create minimum eigen optimizer based on VQE
@@ -272,7 +176,7 @@ print("solution:", z)
 print("solution objective:", tsp.tsp_value(z, adj_matrix))
 draw_tsp_solution(tsp.graph, z, colors, pos)
 
-import qiskit.tools.jupyter
+#import qiskit.tools.jupyter
 
 #%qiskit_version_table
 #%qiskit_copyright
